@@ -88,7 +88,9 @@ def face_recognition(face_path1, face_path2, max_interval=configs.max_interval):
             time.sleep(configs.interval)
             continue
         assert face_ans['status'] == 200
-        return face_ans['result']['score']
+        if face_ans['result']['status'] == 'error':
+            return -1
+        return float(face_ans['result']['score'])
 
     raise exceptions.TimeOutException('[VSOURCE-Lib] 请求超时，未知错误')
 
@@ -145,7 +147,9 @@ def speaker_recognition(speaker_path1, speaker_path2, max_interval=configs.max_i
             time.sleep(configs.interval)
             continue
         assert face_ans['status'] == 200
-        return face_ans['result']['score']
+        if face_ans['result']['status'] == 'error':
+            return -1
+        return float(face_ans['result']['score'])
 
     raise exceptions.TimeOutException('[VSOURCE-Lib] 请求超时，未知错误')
 
@@ -224,6 +228,8 @@ def face_attribute(face_path, max_interval=configs.max_interval):
             continue
         try:
             assert face_ans['status'] == 200
+            if face_ans['result']['status'] == 'error':
+                return []
             return face_ans['result']['result']
         except Exception as e:
             return []
